# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Michał Sawicz <michal@sawicz.net>
from elisa.core.components.model import Model
from elisa.plugins.justintv.common import JustinTVControllerMixin, WWW_HOST,\
    JustinTVMainViewMode
from elisa.plugins.poblesec.base.preview_list import MenuItemListController
from elisa.plugins.poblesec.actions import OpenControllerActionWithItem
from elisa.core.common import application
from elisa.core.utils import defer
from elisa.core.media_uri import MediaUri


class JustinTVCategoryListModel(list, Model):
    def __init__(self, data=None):
        super(JustinTVCategoryListModel, self).__init__()
        if data:
            self.populate(data)
            
    def populate(self, data):
        for id, category_data in data.items():
            self.append(JustinTVCategoryModel(id, category_data))


class JustinTVCategoryModel(Model):
    def __init__(self, id=None, data=None):
        super(JustinTVCategoryModel, self).__init__()
        self.id = None
        self.name = None
        self.subcategories = JustinTVCategoryListModel()
        if id and data:
            self.populate(id, data)
            
    def populate(self, id, data):
        self.id = id
        self.name = data['name']
        if data.has_key('subcategories'):
            self.subcategories.populate(data['subcategories'])


class JustinTVOpenCategoryAction(OpenControllerActionWithItem):
    def execute(self, category):
        self._kwargs['category'] = category
        return self.open_controller(self.path,
                                    category.name,
                                    **self._kwargs)


class JustinTVCategoryViewMode(JustinTVMainViewMode):
    def get_label(self, item):
        return defer.succeed(item.name)


class JustinTVCategoriesController(JustinTVControllerMixin,
                                   MenuItemListController):
    view_mode = JustinTVCategoryViewMode
            
    def populate_model(self):
        def got_categories(categories):
            return categories
        
        muri = MediaUri('http://%s/directory' % WWW_HOST)
        model, dfr = application.resource_manager.get(muri)
        dfr.addCallback(got_categories)
        return dfr
        
    def create_actions(self):
        return JustinTVOpenCategoryAction(self, '/justintv/streams'), []