# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Michał Sawicz <michal@sawicz.net>

from elisa.core.components.model import Model

from elisa.plugins.justintv.category import JustinTVCategoryModel
from elisa.plugins.justintv.common import get_images


class JustinTVChannelListModel(list, Model):
    def __init__(self, data=None):
        super(JustinTVChannelListModel, self).__init__()
        if data:
            self.populate(data)
            
    def populate(self, data):
        for channel_data in data:
            self.append(JustinTVChannelModel(channel_data))


class JustinTVChannelModel(Model):
    def __init__(self, data=None):
        super(JustinTVChannelModel, self).__init__()
        self.id = None
        self.uri = None
        self.login = None
        self.title = None
        self.about = None
        self.description = None
        self.category = None
        self.subcategory = None
        self.language = None
        self.timezone = None
        self.tags = None
        self.mature = None
        self.about = None
        self.producer = None
        self.views_count = None
        self.images = {}
        self.screencaps = {}
        if data:
            self.populate(data)

    def __eq__(self, other):
        if isinstance(other, JustinTVChannelModel):
            return self.id == other.id
        return NotImplemented
    
    def __neq__(self, other):
        result = self.__eq__(other)
        if result is NotImplemented:
            return result
        else:
            return not result
            
    def populate(self, data):
            self.id = data['id']
            self.uri = data['channel_url']
            self.login = data['login']
            self.title = data['title']
            if data.has_key('about'):
                self.about = data['about']
            if data.has_key('description'):
                self.description = data['description']
            self.status = data['status']
            self.category = \
                JustinTVCategoryModel(data['category'],
                                      {'name': data['category_title']})
            self.subcategory = \
                JustinTVCategoryModel(data['subcategory'],
                                      {'name': data['subcategory_title']})
            self.language = data['language']
            self.timezone = data['timezone']
            if data['tags']:
                self.tags = data['tags'].split(' ')
            self.mature = data['mature']
            self.producer = data['producer']
            self.views_count = data['views_count']
            self.images = get_images(data, 'image')
            self.screencaps = get_images(data, 'screen_cap')