# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Michał Sawicz <michal@sawicz.net>

from datetime import datetime, timedelta

from elisa.core.utils import defer
from elisa.core.media_uri import MediaUri
from elisa.core.components.model import Model

from elisa.plugins.base.models.video import VideoModel
from elisa.plugins.base.models.media import PlayableModel

from elisa.plugins.justintv.category import JustinTVCategoryModel
from elisa.plugins.justintv.common import get_images


class JustinTVClipListModel(list, Model):
    def __init__(self, data=None):
        super(JustinTVClipListModel, self).__init__()
        if data:
            self.populate(data)
        
    def populate(self, data):
        for stream_data in data:
            self.append(JustinTVClipModel(stream_data))

class JustinTVClipModel(VideoModel):
    def __init__(self, data=None):
        super(JustinTVClipModel, self).__init__()
        self.id = None
        self.category = None
        self.subcategory = None
        self.start_time = None
        self.length = None
        self.tags = None        
        self.images = {}
        if data:
            self.populate(data)
    
    def populate(self, data):
        self.id = data['id']
        self.title = data['title']
        self.category = JustinTVCategoryModel(data['category'], {'name': data['subcategory_title']})
        self.subcategory = JustinTVCategoryModel(data['subcategory'], {'name': data['subcategory_title']})
        self.start_time = datetime.strptime(data['start_time'], '%Y/%m/%d %H:%M:%S +0000')
        self.length = timedelta(seconds=data['length'])
        self.playable_model = PlayableModel()
        self.playable_model.uri = MediaUri(data['video_file_url'])
        if data['tags']:
            self.tags = data['tags'].split(' ')
        self.images = get_images(data, 'image')
        
    def get_playable_model(self):
        return defer.succeed(self.playable_model)