# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Michał Sawicz <michal@sawicz.net>

from elisa.core.common import application
from elisa.core.utils.i18n import install_translation
from elisa.plugins.poblesec.base.list import GenericListViewMode
from elisa.core.utils import defer
from elisa.plugins.base.models.image import ImageModel
from elisa.core.media_uri import MediaUri

API_KEY = 'zRNNGDit5nNxXl3ZHKpvg'
API_SECRET = 'vQaiU5a9Lrsp71W8HiN5U5ne3nc7VrXnr9eS9Unm4' 

API_HOST = 'api.justin.tv'
WWW_HOST = 'www.justin.tv'

_ = install_translation('justintv')

def get_justintv_provider():
    provider_path = "elisa.plugins.justintv.resource_provider:"\
                    "JustinTVResourceProvider"
    manager = application.resource_manager
    provider = manager.get_resource_provider_by_path(provider_path)

    return provider

def get_images(data, prefix):
    """
    Get ImageModels from JustinTV JSON object
    """
    images = []
    for size in ['tiny', 'small', 'medium', 'large', 'huge']:
        key = '%s_url_%s' % (prefix, size)
        try:
            data[key].find('404_user')
        except KeyError:
            pass
        except ValueError:
            images[size] = ImageModel()
            images[size].references.append(MediaUri(data[key]))
    return images


class JustinTVMainViewMode(GenericListViewMode):
    def get_label(self, item):
        return defer.succeed(item.title)
    
    def get_default_image(self, item):
        return 'elisa.plugins.poblesec.glyphs.small.video'
    
    def get_image(self, item, theme):
        return None


class JustinTVControllerMixin(object):
    view_mode = JustinTVMainViewMode
    empty_label = _('The web service did not return any result.')
    crumbs_logo = 'elisa.plugins.justintv.logo'
    item_widget_kwargs = {'with_artwork_box': False}