# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Michał Sawicz <michal@sawicz.net>
from elisa.plugins.justintv.common import get_justintv_provider, WWW_HOST,\
    JustinTVControllerMixin
from elisa.plugins.justintv.channel import JustinTVChannelModel
from elisa.core.common import application
from elisa.plugins.poblesec.base.preview_list import MenuItemListController
from elisa.plugins.poblesec.actions import OpenControllerActionWithItem
from elisa.core.media_uri import MediaUri
from elisa.plugins.base.messages.error_message import ErrorMessage
from elisa.plugins.poblesec.errors_handling import error_message_treatment
from elisa.core.action import ContextualAction
from elisa.core.utils.i18n import install_translation
import cgi

_ = install_translation('justintv')

class JustinTVFavoriteAction(ContextualAction):
    def __init__(self, controller, name):
        super(JustinTVFavoriteAction, self).__init__(controller)
        self.name = name
    
    def failed(self, error):
        frontend = self.controller.frontend
        main_controller = frontend.controller
        message = ErrorMessage(cgi.escape(str(error)))
        return error_message_treatment(main_controller, message, self)    

    def added(self, model, channel):
        self.provider.clear_favorites()
        self.name = 'remove'

    def removed(self, model, channel):
        self.provider.clear_favorites()
        self.name = 'add'

    def execute(self, item):
        self.provider = get_justintv_provider()
            
        if isinstance(item, JustinTVChannelModel):
            channel = item
        else:
            channel = item.channel
        
        def _add():
            uri = 'http://%s/%s/favorite' % (WWW_HOST, channel.login) 
            _, dfr = application.resource_manager.post(MediaUri(uri))
            dfr.addCallback(self.added, channel)
            dfr.addErrback(self.failed)
            return dfr
            
        def _remove():
            uri = 'http://%s/%s/not_favorite' % (WWW_HOST, channel.login) 
            _, dfr = application.resource_manager.post(MediaUri(uri))
            dfr.addCallback(self.removed, channel)
            dfr.addErrback(self.failed)
            return dfr
        
        if self.name == 'add':
            return _add()
        elif self.name == 'remove':
            return _remove()


class JustinTVFavoriteListAction(JustinTVFavoriteAction):
    def __init__(self, controller):
        super(JustinTVFavoriteListAction, self).__init__(controller, 'remove')
        
    def removed(self, model, item):
        self.provider.clear_favorites()
        self.controller.model.remove(item)

    
class JustinTVFavoritesController(JustinTVControllerMixin,
                                  MenuItemListController):
    empty_label = _('You don\'t have any favorites.')
    item_widget_kwargs = {'with_artwork_box': True}

    def populate_model(self):                
        provider = get_justintv_provider()
        dfr = provider.get_favorites()     
        return dfr
        
    def create_actions(self):
        return (OpenControllerActionWithItem(self, '/justin/channel'), 
                [JustinTVFavoriteListAction(self)])