# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Michał Sawicz <michal@sawicz.net>
from elisa.core.utils import defer
from elisa.core.utils.i18n import install_translation

from elisa.plugins.poblesec.base.preview_list import MenuItemPreviewListController
from elisa.plugins.poblesec.link import Link, LinksMenuController

from elisa.plugins.justintv.common import get_justintv_provider,\
    JustinTVControllerMixin
from elisa.plugins.justintv.user import JustinTVLogoutAction

_ = install_translation('justintv')
_p = install_translation('poblesec')


def justintv_decorator(controller):
    controller.append_plugin('justintv', _('Justin.TV'), '/justintv')
    return defer.succeed(None)


class JustinTVMainController(JustinTVControllerMixin,
                                LinksMenuController,
                                MenuItemPreviewListController):

    def populate_model(self):
        def logged_in(data):
            link_presets = Link(controller_path='/justintv/favorites', 
                                label=_('My Favorites'))
            links.append(link_presets)
            link_log = Link(label=_('Logout from Justin.TV'))
            link_log.default_action=JustinTVLogoutAction(self)
            links.append(link_log)
            return links
            
        def not_logged_in(data):
            link_log = Link(controller_path='/justintv/login', label=_('Login to Justin.TV'))
            links.append(link_log)
            return links
        
        provider = get_justintv_provider()

        link_search = Link(controller_path='/justintv/search', 
                           label=_p('Search'), 
                           controller_args={'mediatype':'video'})
        link_browse = Link(controller_path='/justintv/categories', 
                           label=_('Browse Streams'))
        links = [link_search, link_browse]

        dfr = provider.login()
        dfr.addCallback(logged_in)
        dfr.addErrback(not_logged_in)
        return dfr

def use_me_hook(frontend):
    browser = frontend.retrieve_controllers('/poblesec/browser')[0]
    paths = [('/poblesec/internet_menu', _p('INTERNET MEDIA'), {}),
             ('/poblesec/video/internet', _p('Video'), {}),
             ('/justintv', _('Justin.TV'), {})]
    return browser.navigate(paths)
