# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Michał Sawicz <michal@sawicz.net>

from elisa.core.components.model import Model

from elisa.plugins.justintv.channel import JustinTVChannelModel
from elisa.plugins.justintv.common import JustinTVControllerMixin, WWW_HOST,\
    JustinTVMainViewMode, get_justintv_provider
from elisa.plugins.poblesec.base.preview_list import MenuItemListController
from elisa.core.media_uri import MediaUri
from elisa.core.common import application
from elisa.plugins.poblesec.actions import OpenControllerActionWithItem
from elisa.core.utils import defer
from elisa.plugins.justintv.favorite import JustinTVFavoriteAction

class JustinTVStreamListModel(list, Model):
    def __init__(self, data=None):
        super(JustinTVStreamListModel, self).__init__()
        if data:
            self.populate(data)
        
    def populate(self, data):
        for stream_data in data:
            self.append(JustinTVStreamModel(stream_data))

class JustinTVStreamModel(Model):
    def __init__(self, data=None):
        super(JustinTVStreamModel, self).__init__()
        self.id = None
        self.title = None
        self.name = None
        self.language = None
        self.channel = None
        if data:
            self.populate(data)
    
    def populate(self, data):
        self.id = data['id']
        self.name = data['name']
        if data.has_key('language'):
            self.language = data['language']
        self.channel = JustinTVChannelModel(data['channel'])
        if data.has_key('title'):
            self.title = data['title']


class JustinTVStreamViewMode(JustinTVMainViewMode):
    def get_label(self, item):
        if item.title:
            return defer.succeed(item.title)
        else:
            return defer.succeed(item.channel.title)


class JustinTVStreamsController(JustinTVControllerMixin,
                                   MenuItemListController):
    view_mode = JustinTVStreamViewMode
    item_widget_kwargs = {'with_artwork_box': True}

    def initialize(self, category, **kwargs):
        self._category = category
        return super(JustinTVStreamsController, self).initialize(**kwargs)
            
    def populate_model(self):
        def got_favorites(favorites):
            def got_streams(streams):
                for stream in streams:
                    if stream.channel in favorites:
                        stream.extra_actions = \
                            [JustinTVFavoriteAction(self, 'remove')]
                    else:
                        stream.extra_actions = \
                            [JustinTVFavoriteAction(self, 'add')]
                return streams
            muri = MediaUri('http://%s/directory/%s' % (WWW_HOST, self._category.id))
            model, dfr = application.resource_manager.get(muri)
            dfr.addCallback(got_streams)
            return dfr
                
        provider = get_justintv_provider()
        dfr = provider.get_favorites()
        dfr.addCallback(got_favorites)     
        return dfr
        
    def create_actions(self):
        return OpenControllerActionWithItem(self, '/justin/channel'), []