# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Michał Sawicz <michal@sawicz.net>
from elisa.core.components.model import Model
from elisa.core.action import ContextualAction
from elisa.core.utils.i18n import install_translation

from elisa.plugins.poblesec.login import LoginController

from elisa.plugins.justintv.common import get_justintv_provider,\
    JustinTVControllerMixin, get_images

_ = install_translation('justintv')
_p = install_translation('poblesec')

class JustinTVUserModel(Model):
    def __init__(self, data=None):
        super(JustinTVUserModel, self).__init__()
        self.id = None
        self.login = None
        self.name = None
        self.broadcaster = None
        self.sex = None
        self.about = None
        self.quotes = None
        self.location = None
        self.images = {}
        if data:
            self.populate(data)
        
    def populate(self, data):
        self.id = data['id']
        self.login = data['login']
        self.name = data['name']
        self.broadcaster = data['broadcaster']
        self.sex = data['sex']
        if data.has_key('about'):
            self.about = data['about']
        self.quotes = data['favorite_quotes']
        self.location = data['location']
        self.images = get_images(data, 'image')
        

class JustinTVLoginController(JustinTVControllerMixin, LoginController):   
    def login(self, username, password):    
        provider = get_justintv_provider() 
        return provider.login(username, password)

    def success(self, result):
        browser = self.frontend.retrieve_controllers('/poblesec/browser')[0]
        paths = [('/poblesec/internet_menu', _p('INTERNET MEDIA'), {}),
                 ('/poblesec/video/internet', _p('Radio'), {}),
                 ('/justintv', _('Justin.TV'), {})]
        return browser.navigate(paths)


class JustinTVLogoutAction(ContextualAction):
    def execute(self, item):

        provider = get_justintv_provider()
        provider.logout()
        
        browser = self.controller.frontend.retrieve_controllers('/poblesec/browser')[0]
        paths = [('/poblesec/internet_menu', _p('INTERNET MEDIA'), {}),
                 ('/poblesec/video/internet', _p('Radio'), {}),
                 ('/justintv', _('Justin.TV'), {})]
        return browser.navigate(paths)